# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.order_confirmation import OrderConfirmation  # noqa: E501
from swagger_client.rest import ApiException


class TestOrderConfirmation(unittest.TestCase):
    """OrderConfirmation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrderConfirmation(self):
        """Test OrderConfirmation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.order_confirmation.OrderConfirmation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Settlement(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'market_result': 'str',
        'no_count': 'int',
        'no_total_cost': 'Cent',
        'revenue': 'Cent',
        'settled_time': 'OutputTime',
        'ticker': 'str',
        'yes_count': 'int',
        'yes_total_cost': 'Cent'
    }

    attribute_map = {
        'market_result': 'market_result',
        'no_count': 'no_count',
        'no_total_cost': 'no_total_cost',
        'revenue': 'revenue',
        'settled_time': 'settled_time',
        'ticker': 'ticker',
        'yes_count': 'yes_count',
        'yes_total_cost': 'yes_total_cost'
    }

    def __init__(self, market_result=None, no_count=None, no_total_cost=None, revenue=None, settled_time=None, ticker=None, yes_count=None, yes_total_cost=None):  # noqa: E501
        """Settlement - a model defined in Swagger"""  # noqa: E501
        self._market_result = None
        self._no_count = None
        self._no_total_cost = None
        self._revenue = None
        self._settled_time = None
        self._ticker = None
        self._yes_count = None
        self._yes_total_cost = None
        self.discriminator = None
        self.market_result = market_result
        self.no_count = no_count
        self.no_total_cost = no_total_cost
        self.revenue = revenue
        self.settled_time = settled_time
        self.ticker = ticker
        self.yes_count = yes_count
        self.yes_total_cost = yes_total_cost

    @property
    def market_result(self):
        """Gets the market_result of this Settlement.  # noqa: E501

        Settlement result for this market.  # noqa: E501

        :return: The market_result of this Settlement.  # noqa: E501
        :rtype: str
        """
        return self._market_result

    @market_result.setter
    def market_result(self, market_result):
        """Sets the market_result of this Settlement.

        Settlement result for this market.  # noqa: E501

        :param market_result: The market_result of this Settlement.  # noqa: E501
        :type: str
        """
        if market_result is None:
            raise ValueError("Invalid value for `market_result`, must not be `None`")  # noqa: E501

        self._market_result = market_result

    @property
    def no_count(self):
        """Gets the no_count of this Settlement.  # noqa: E501

        Number of no contracts owned on settlement.  # noqa: E501

        :return: The no_count of this Settlement.  # noqa: E501
        :rtype: int
        """
        return self._no_count

    @no_count.setter
    def no_count(self, no_count):
        """Sets the no_count of this Settlement.

        Number of no contracts owned on settlement.  # noqa: E501

        :param no_count: The no_count of this Settlement.  # noqa: E501
        :type: int
        """
        if no_count is None:
            raise ValueError("Invalid value for `no_count`, must not be `None`")  # noqa: E501

        self._no_count = no_count

    @property
    def no_total_cost(self):
        """Gets the no_total_cost of this Settlement.  # noqa: E501


        :return: The no_total_cost of this Settlement.  # noqa: E501
        :rtype: Cent
        """
        return self._no_total_cost

    @no_total_cost.setter
    def no_total_cost(self, no_total_cost):
        """Sets the no_total_cost of this Settlement.


        :param no_total_cost: The no_total_cost of this Settlement.  # noqa: E501
        :type: Cent
        """
        if no_total_cost is None:
            raise ValueError("Invalid value for `no_total_cost`, must not be `None`")  # noqa: E501

        self._no_total_cost = no_total_cost

    @property
    def revenue(self):
        """Gets the revenue of this Settlement.  # noqa: E501


        :return: The revenue of this Settlement.  # noqa: E501
        :rtype: Cent
        """
        return self._revenue

    @revenue.setter
    def revenue(self, revenue):
        """Sets the revenue of this Settlement.


        :param revenue: The revenue of this Settlement.  # noqa: E501
        :type: Cent
        """
        if revenue is None:
            raise ValueError("Invalid value for `revenue`, must not be `None`")  # noqa: E501

        self._revenue = revenue

    @property
    def settled_time(self):
        """Gets the settled_time of this Settlement.  # noqa: E501


        :return: The settled_time of this Settlement.  # noqa: E501
        :rtype: OutputTime
        """
        return self._settled_time

    @settled_time.setter
    def settled_time(self, settled_time):
        """Sets the settled_time of this Settlement.


        :param settled_time: The settled_time of this Settlement.  # noqa: E501
        :type: OutputTime
        """
        if settled_time is None:
            raise ValueError("Invalid value for `settled_time`, must not be `None`")  # noqa: E501

        self._settled_time = settled_time

    @property
    def ticker(self):
        """Gets the ticker of this Settlement.  # noqa: E501

        Unique identifier for markets.  # noqa: E501

        :return: The ticker of this Settlement.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this Settlement.

        Unique identifier for markets.  # noqa: E501

        :param ticker: The ticker of this Settlement.  # noqa: E501
        :type: str
        """
        if ticker is None:
            raise ValueError("Invalid value for `ticker`, must not be `None`")  # noqa: E501

        self._ticker = ticker

    @property
    def yes_count(self):
        """Gets the yes_count of this Settlement.  # noqa: E501

        Number of yes contracts owned on settlement.  # noqa: E501

        :return: The yes_count of this Settlement.  # noqa: E501
        :rtype: int
        """
        return self._yes_count

    @yes_count.setter
    def yes_count(self, yes_count):
        """Sets the yes_count of this Settlement.

        Number of yes contracts owned on settlement.  # noqa: E501

        :param yes_count: The yes_count of this Settlement.  # noqa: E501
        :type: int
        """
        if yes_count is None:
            raise ValueError("Invalid value for `yes_count`, must not be `None`")  # noqa: E501

        self._yes_count = yes_count

    @property
    def yes_total_cost(self):
        """Gets the yes_total_cost of this Settlement.  # noqa: E501


        :return: The yes_total_cost of this Settlement.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_total_cost

    @yes_total_cost.setter
    def yes_total_cost(self, yes_total_cost):
        """Sets the yes_total_cost of this Settlement.


        :param yes_total_cost: The yes_total_cost of this Settlement.  # noqa: E501
        :type: Cent
        """
        if yes_total_cost is None:
            raise ValueError("Invalid value for `yes_total_cost`, must not be `None`")  # noqa: E501

        self._yes_total_cost = yes_total_cost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Settlement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Settlement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from kalshi_python.api.auth_api import AuthApi
from kalshi_python.api.exchange_api import ExchangeApi
from kalshi_python.api.market_api import MarketApi
from kalshi_python.api.portfolio_api import PortfolioApi
# import ApiClient
from kalshi_python.api_client import ApiClient
from kalshi_python.api_instance import ApiInstance
from kalshi_python.configuration import Configuration
# import models into sdk package
from kalshi_python.models.batch_cancel_orders_individual_response import BatchCancelOrdersIndividualResponse
from kalshi_python.models.batch_cancel_orders_request import BatchCancelOrdersRequest
from kalshi_python.models.batch_cancel_orders_response import BatchCancelOrdersResponse
from kalshi_python.models.batch_create_orders_individual_response import BatchCreateOrdersIndividualResponse
from kalshi_python.models.batch_create_orders_request import BatchCreateOrdersRequest
from kalshi_python.models.batch_create_orders_response import BatchCreateOrdersResponse
from kalshi_python.models.cancel_order_response import CancelOrderResponse
from kalshi_python.models.cent import Cent
from kalshi_python.models.create_order_request import CreateOrderRequest
from kalshi_python.models.create_order_response import CreateOrderResponse
from kalshi_python.models.decrease_order_request import DecreaseOrderRequest
from kalshi_python.models.decrease_order_response import DecreaseOrderResponse
from kalshi_python.models.event_data import EventData
from kalshi_python.models.event_position import EventPosition
from kalshi_python.models.exchange_status import ExchangeStatus
from kalshi_python.models.fill import Fill
from kalshi_python.models.fills import Fills
from kalshi_python.models.get_balance_response import GetBalanceResponse
from kalshi_python.models.get_event_response import GetEventResponse
from kalshi_python.models.get_fills_response import GetFillsResponse
from kalshi_python.models.get_market_history_response import GetMarketHistoryResponse
from kalshi_python.models.get_market_orderbook_response import GetMarketOrderbookResponse
from kalshi_python.models.get_market_response import GetMarketResponse
from kalshi_python.models.get_markets_response import GetMarketsResponse
from kalshi_python.models.get_order_response import GetOrderResponse
from kalshi_python.models.get_orders_response import GetOrdersResponse
from kalshi_python.models.get_portfolio_settlements_response import GetPortfolioSettlementsResponse
from kalshi_python.models.get_positions_response import GetPositionsResponse
from kalshi_python.models.get_series_response import GetSeriesResponse
from kalshi_python.models.json_error import JSONError
from kalshi_python.models.login_request import LoginRequest
from kalshi_python.models.login_response import LoginResponse
from kalshi_python.models.market import Market
from kalshi_python.models.market_position import MarketPosition
from kalshi_python.models.market_stats_point import MarketStatsPoint
from kalshi_python.models.number import Number
from kalshi_python.models.order import Order
from kalshi_python.models.order_book import OrderBook
from kalshi_python.models.order_confirmation import OrderConfirmation
from kalshi_python.models.order_list import OrderList
from kalshi_python.models.order_status import OrderStatus
from kalshi_python.models.order_type import OrderType
from kalshi_python.models.output_time import OutputTime
from kalshi_python.models.price_level import PriceLevel
from kalshi_python.models.public_trade import PublicTrade
from kalshi_python.models.public_trade_list import PublicTradeList
from kalshi_python.models.public_trades_get_response import PublicTradesGetResponse
from kalshi_python.models.series import Series
from kalshi_python.models.settlement import Settlement



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateOrderRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'action': 'str',
        'buy_max_cost': 'Cent',
        'client_order_id': 'str',
        'count': 'int',
        'expiration_ts': 'int',
        'no_price': 'Cent',
        'sell_position_floor': 'int',
        'side': 'str',
        'ticker': 'str',
        'type': 'str',
        'yes_price': 'Cent'
    }

    attribute_map = {
        'action': 'action',
        'buy_max_cost': 'buy_max_cost',
        'client_order_id': 'client_order_id',
        'count': 'count',
        'expiration_ts': 'expiration_ts',
        'no_price': 'no_price',
        'sell_position_floor': 'sell_position_floor',
        'side': 'side',
        'ticker': 'ticker',
        'type': 'type',
        'yes_price': 'yes_price'
    }

    def __init__(self, action=None, buy_max_cost=None, client_order_id=None, count=None, expiration_ts=None, no_price=None, sell_position_floor=None, side=None, ticker=None, type=None, yes_price=None):  # noqa: E501
        """CreateOrderRequest - a model defined in Swagger"""  # noqa: E501
        self._action = None
        self._buy_max_cost = None
        self._client_order_id = None
        self._count = None
        self._expiration_ts = None
        self._no_price = None
        self._sell_position_floor = None
        self._side = None
        self._ticker = None
        self._type = None
        self._yes_price = None
        self.discriminator = None
        self.action = action
        if buy_max_cost is not None:
            self.buy_max_cost = buy_max_cost
        self.client_order_id = client_order_id
        self.count = count
        if expiration_ts is not None:
            self.expiration_ts = expiration_ts
        if no_price is not None:
            self.no_price = no_price
        if sell_position_floor is not None:
            self.sell_position_floor = sell_position_floor
        self.side = side
        self.ticker = ticker
        self.type = type
        if yes_price is not None:
            self.yes_price = yes_price

    @property
    def action(self):
        """Gets the action of this CreateOrderRequest.  # noqa: E501

        Specifies if this is a buy or sell order.  # noqa: E501

        :return: The action of this CreateOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this CreateOrderRequest.

        Specifies if this is a buy or sell order.  # noqa: E501

        :param action: The action of this CreateOrderRequest.  # noqa: E501
        :type: str
        """
        if action is None:
            raise ValueError("Invalid value for `action`, must not be `None`")  # noqa: E501

        self._action = action

    @property
    def buy_max_cost(self):
        """Gets the buy_max_cost of this CreateOrderRequest.  # noqa: E501


        :return: The buy_max_cost of this CreateOrderRequest.  # noqa: E501
        :rtype: Cent
        """
        return self._buy_max_cost

    @buy_max_cost.setter
    def buy_max_cost(self, buy_max_cost):
        """Sets the buy_max_cost of this CreateOrderRequest.


        :param buy_max_cost: The buy_max_cost of this CreateOrderRequest.  # noqa: E501
        :type: Cent
        """

        self._buy_max_cost = buy_max_cost

    @property
    def client_order_id(self):
        """Gets the client_order_id of this CreateOrderRequest.  # noqa: E501

        Member-provided UUID to attach to the order.  # noqa: E501

        :return: The client_order_id of this CreateOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_order_id

    @client_order_id.setter
    def client_order_id(self, client_order_id):
        """Sets the client_order_id of this CreateOrderRequest.

        Member-provided UUID to attach to the order.  # noqa: E501

        :param client_order_id: The client_order_id of this CreateOrderRequest.  # noqa: E501
        :type: str
        """
        if client_order_id is None:
            raise ValueError("Invalid value for `client_order_id`, must not be `None`")  # noqa: E501

        self._client_order_id = client_order_id

    @property
    def count(self):
        """Gets the count of this CreateOrderRequest.  # noqa: E501

        Number of contracts to be bought or sold.  # noqa: E501

        :return: The count of this CreateOrderRequest.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this CreateOrderRequest.

        Number of contracts to be bought or sold.  # noqa: E501

        :param count: The count of this CreateOrderRequest.  # noqa: E501
        :type: int
        """
        if count is None:
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def expiration_ts(self):
        """Gets the expiration_ts of this CreateOrderRequest.  # noqa: E501

        Expiration time of the order, in unix seconds.  If this is not supplied, the order won't expire until explicitly cancelled. This is also known as Good 'Till Cancelled (GTC).  If the time is in the past, the order will attempt to partially or completely fill and the remaining unfilled quantity will be cancelled. This is also known as Immediate-or-Cancel (IOC).  If the time is in the future, the remaining unfilled quantity order will expire at the specified time.  # noqa: E501

        :return: The expiration_ts of this CreateOrderRequest.  # noqa: E501
        :rtype: int
        """
        return self._expiration_ts

    @expiration_ts.setter
    def expiration_ts(self, expiration_ts):
        """Sets the expiration_ts of this CreateOrderRequest.

        Expiration time of the order, in unix seconds.  If this is not supplied, the order won't expire until explicitly cancelled. This is also known as Good 'Till Cancelled (GTC).  If the time is in the past, the order will attempt to partially or completely fill and the remaining unfilled quantity will be cancelled. This is also known as Immediate-or-Cancel (IOC).  If the time is in the future, the remaining unfilled quantity order will expire at the specified time.  # noqa: E501

        :param expiration_ts: The expiration_ts of this CreateOrderRequest.  # noqa: E501
        :type: int
        """

        self._expiration_ts = expiration_ts

    @property
    def no_price(self):
        """Gets the no_price of this CreateOrderRequest.  # noqa: E501


        :return: The no_price of this CreateOrderRequest.  # noqa: E501
        :rtype: Cent
        """
        return self._no_price

    @no_price.setter
    def no_price(self, no_price):
        """Sets the no_price of this CreateOrderRequest.


        :param no_price: The no_price of this CreateOrderRequest.  # noqa: E501
        :type: Cent
        """

        self._no_price = no_price

    @property
    def sell_position_floor(self):
        """Gets the sell_position_floor of this CreateOrderRequest.  # noqa: E501

        SellPositionFloor will not let you flip position for a market order if set to 0.  # noqa: E501

        :return: The sell_position_floor of this CreateOrderRequest.  # noqa: E501
        :rtype: int
        """
        return self._sell_position_floor

    @sell_position_floor.setter
    def sell_position_floor(self, sell_position_floor):
        """Sets the sell_position_floor of this CreateOrderRequest.

        SellPositionFloor will not let you flip position for a market order if set to 0.  # noqa: E501

        :param sell_position_floor: The sell_position_floor of this CreateOrderRequest.  # noqa: E501
        :type: int
        """

        self._sell_position_floor = sell_position_floor

    @property
    def side(self):
        """Gets the side of this CreateOrderRequest.  # noqa: E501

        Specifies if this is a 'yes' or 'no' order.  # noqa: E501

        :return: The side of this CreateOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._side

    @side.setter
    def side(self, side):
        """Sets the side of this CreateOrderRequest.

        Specifies if this is a 'yes' or 'no' order.  # noqa: E501

        :param side: The side of this CreateOrderRequest.  # noqa: E501
        :type: str
        """
        if side is None:
            raise ValueError("Invalid value for `side`, must not be `None`")  # noqa: E501

        self._side = side

    @property
    def ticker(self):
        """Gets the ticker of this CreateOrderRequest.  # noqa: E501

        The ticker of the market the order will be placed in.  # noqa: E501

        :return: The ticker of this CreateOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this CreateOrderRequest.

        The ticker of the market the order will be placed in.  # noqa: E501

        :param ticker: The ticker of this CreateOrderRequest.  # noqa: E501
        :type: str
        """
        if ticker is None:
            raise ValueError("Invalid value for `ticker`, must not be `None`")  # noqa: E501

        self._ticker = ticker

    @property
    def type(self):
        """Gets the type of this CreateOrderRequest.  # noqa: E501

        Specifies if this is a \"market\" or a \"limit\" order. Note that either the Yes Price or the No Price must be provided for limit orders.  # noqa: E501

        :return: The type of this CreateOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateOrderRequest.

        Specifies if this is a \"market\" or a \"limit\" order. Note that either the Yes Price or the No Price must be provided for limit orders.  # noqa: E501

        :param type: The type of this CreateOrderRequest.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def yes_price(self):
        """Gets the yes_price of this CreateOrderRequest.  # noqa: E501


        :return: The yes_price of this CreateOrderRequest.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_price

    @yes_price.setter
    def yes_price(self, yes_price):
        """Sets the yes_price of this CreateOrderRequest.


        :param yes_price: The yes_price of this CreateOrderRequest.  # noqa: E501
        :type: Cent
        """

        self._yes_price = yes_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateOrderRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateOrderRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EventPosition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'event_exposure': 'Cent',
        'event_ticker': 'str',
        'fees_paid': 'Cent',
        'realized_pnl': 'Cent',
        'resting_order_count': 'int',
        'total_cost': 'Cent'
    }

    attribute_map = {
        'event_exposure': 'event_exposure',
        'event_ticker': 'event_ticker',
        'fees_paid': 'fees_paid',
        'realized_pnl': 'realized_pnl',
        'resting_order_count': 'resting_order_count',
        'total_cost': 'total_cost'
    }

    def __init__(self, event_exposure=None, event_ticker=None, fees_paid=None, realized_pnl=None, resting_order_count=None, total_cost=None):  # noqa: E501
        """EventPosition - a model defined in Swagger"""  # noqa: E501
        self._event_exposure = None
        self._event_ticker = None
        self._fees_paid = None
        self._realized_pnl = None
        self._resting_order_count = None
        self._total_cost = None
        self.discriminator = None
        self.event_exposure = event_exposure
        self.event_ticker = event_ticker
        self.fees_paid = fees_paid
        self.realized_pnl = realized_pnl
        self.resting_order_count = resting_order_count
        self.total_cost = total_cost

    @property
    def event_exposure(self):
        """Gets the event_exposure of this EventPosition.  # noqa: E501


        :return: The event_exposure of this EventPosition.  # noqa: E501
        :rtype: Cent
        """
        return self._event_exposure

    @event_exposure.setter
    def event_exposure(self, event_exposure):
        """Sets the event_exposure of this EventPosition.


        :param event_exposure: The event_exposure of this EventPosition.  # noqa: E501
        :type: Cent
        """
        if event_exposure is None:
            raise ValueError("Invalid value for `event_exposure`, must not be `None`")  # noqa: E501

        self._event_exposure = event_exposure

    @property
    def event_ticker(self):
        """Gets the event_ticker of this EventPosition.  # noqa: E501

        Unique identifier for events.  # noqa: E501

        :return: The event_ticker of this EventPosition.  # noqa: E501
        :rtype: str
        """
        return self._event_ticker

    @event_ticker.setter
    def event_ticker(self, event_ticker):
        """Sets the event_ticker of this EventPosition.

        Unique identifier for events.  # noqa: E501

        :param event_ticker: The event_ticker of this EventPosition.  # noqa: E501
        :type: str
        """
        if event_ticker is None:
            raise ValueError("Invalid value for `event_ticker`, must not be `None`")  # noqa: E501

        self._event_ticker = event_ticker

    @property
    def fees_paid(self):
        """Gets the fees_paid of this EventPosition.  # noqa: E501


        :return: The fees_paid of this EventPosition.  # noqa: E501
        :rtype: Cent
        """
        return self._fees_paid

    @fees_paid.setter
    def fees_paid(self, fees_paid):
        """Sets the fees_paid of this EventPosition.


        :param fees_paid: The fees_paid of this EventPosition.  # noqa: E501
        :type: Cent
        """
        if fees_paid is None:
            raise ValueError("Invalid value for `fees_paid`, must not be `None`")  # noqa: E501

        self._fees_paid = fees_paid

    @property
    def realized_pnl(self):
        """Gets the realized_pnl of this EventPosition.  # noqa: E501


        :return: The realized_pnl of this EventPosition.  # noqa: E501
        :rtype: Cent
        """
        return self._realized_pnl

    @realized_pnl.setter
    def realized_pnl(self, realized_pnl):
        """Sets the realized_pnl of this EventPosition.


        :param realized_pnl: The realized_pnl of this EventPosition.  # noqa: E501
        :type: Cent
        """
        if realized_pnl is None:
            raise ValueError("Invalid value for `realized_pnl`, must not be `None`")  # noqa: E501

        self._realized_pnl = realized_pnl

    @property
    def resting_order_count(self):
        """Gets the resting_order_count of this EventPosition.  # noqa: E501

        Aggregate size of resting orders in contract units.  # noqa: E501

        :return: The resting_order_count of this EventPosition.  # noqa: E501
        :rtype: int
        """
        return self._resting_order_count

    @resting_order_count.setter
    def resting_order_count(self, resting_order_count):
        """Sets the resting_order_count of this EventPosition.

        Aggregate size of resting orders in contract units.  # noqa: E501

        :param resting_order_count: The resting_order_count of this EventPosition.  # noqa: E501
        :type: int
        """
        if resting_order_count is None:
            raise ValueError("Invalid value for `resting_order_count`, must not be `None`")  # noqa: E501

        self._resting_order_count = resting_order_count

    @property
    def total_cost(self):
        """Gets the total_cost of this EventPosition.  # noqa: E501


        :return: The total_cost of this EventPosition.  # noqa: E501
        :rtype: Cent
        """
        return self._total_cost

    @total_cost.setter
    def total_cost(self, total_cost):
        """Sets the total_cost of this EventPosition.


        :param total_cost: The total_cost of this EventPosition.  # noqa: E501
        :type: Cent
        """
        if total_cost is None:
            raise ValueError("Invalid value for `total_cost`, must not be `None`")  # noqa: E501

        self._total_cost = total_cost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventPosition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventPosition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kalshi_python.api_client import ApiClient


class MarketApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_event(self, event_ticker, **kwargs):  # noqa: E501
        """GetEvent  # noqa: E501

        Endpoint for getting data about an event by its ticker.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_event(event_ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_ticker: Should be filled with the ticker of the event. (required)
        :return: GetEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_event_with_http_info(event_ticker, **kwargs)  # noqa: E501
        else:
            (data) = self.get_event_with_http_info(event_ticker, **kwargs)  # noqa: E501
            return data

    def get_event_with_http_info(self, event_ticker, **kwargs):  # noqa: E501
        """GetEvent  # noqa: E501

        Endpoint for getting data about an event by its ticker.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_event_with_http_info(event_ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_ticker: Should be filled with the ticker of the event. (required)
        :return: GetEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_ticker']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_ticker' is set
        if ('event_ticker' not in params or
                params['event_ticker'] is None):
            raise ValueError("Missing the required parameter `event_ticker` when calling `get_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_ticker' in params:
            path_params['event_ticker'] = params['event_ticker']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/events/{event_ticker}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetEventResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_market(self, ticker, **kwargs):  # noqa: E501
        """GetMarket  # noqa: E501

        Endpoint for getting data about a specific market.  The value for the ticker path parameter should match the ticker of the target market.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_market(ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Market ticker for the market being retrieved. (required)
        :return: GetMarketResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_market_with_http_info(ticker, **kwargs)  # noqa: E501
        else:
            (data) = self.get_market_with_http_info(ticker, **kwargs)  # noqa: E501
            return data

    def get_market_with_http_info(self, ticker, **kwargs):  # noqa: E501
        """GetMarket  # noqa: E501

        Endpoint for getting data about a specific market.  The value for the ticker path parameter should match the ticker of the target market.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_market_with_http_info(ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Market ticker for the market being retrieved. (required)
        :return: GetMarketResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ticker']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_market" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ticker' is set
        if ('ticker' not in params or
                params['ticker'] is None):
            raise ValueError("Missing the required parameter `ticker` when calling `get_market`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'ticker' in params:
            path_params['ticker'] = params['ticker']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/markets/{ticker}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetMarketResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_market_history(self, ticker, **kwargs):  # noqa: E501
        """GetMarketHistory  # noqa: E501

        Endpoint for getting the statistics history for a market.  The value for the ticker path parameter should match the ticker of the target market. The min_ts parameter is optional, and will restrict statistics to those after provided timestamp. The min_ts is inclusive, which means a market history point at min_ts will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_market_history(ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Market ticker (required)
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like max_ts or min_ts were passed in the original query they must be passed again.
        :param int min_ts: If provided, MinTs restricts history to trades starting from MinTs.  Default value: 1 hour ago.
        :param int max_ts: If provided, MaxTs restricts history to trades up until MaxTs
        :return: GetMarketHistoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_market_history_with_http_info(ticker, **kwargs)  # noqa: E501
        else:
            (data) = self.get_market_history_with_http_info(ticker, **kwargs)  # noqa: E501
            return data

    def get_market_history_with_http_info(self, ticker, **kwargs):  # noqa: E501
        """GetMarketHistory  # noqa: E501

        Endpoint for getting the statistics history for a market.  The value for the ticker path parameter should match the ticker of the target market. The min_ts parameter is optional, and will restrict statistics to those after provided timestamp. The min_ts is inclusive, which means a market history point at min_ts will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_market_history_with_http_info(ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Market ticker (required)
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like max_ts or min_ts were passed in the original query they must be passed again.
        :param int min_ts: If provided, MinTs restricts history to trades starting from MinTs.  Default value: 1 hour ago.
        :param int max_ts: If provided, MaxTs restricts history to trades up until MaxTs
        :return: GetMarketHistoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ticker', 'limit', 'cursor', 'min_ts', 'max_ts']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_market_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ticker' is set
        if ('ticker' not in params or
                params['ticker'] is None):
            raise ValueError("Missing the required parameter `ticker` when calling `get_market_history`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'ticker' in params:
            path_params['ticker'] = params['ticker']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501
        if 'min_ts' in params:
            query_params.append(('min_ts', params['min_ts']))  # noqa: E501
        if 'max_ts' in params:
            query_params.append(('max_ts', params['max_ts']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/markets/{ticker}/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetMarketHistoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_market_orderbook(self, ticker, **kwargs):  # noqa: E501
        """GetMarketOrderbook  # noqa: E501

        Endpoint for getting the orderbook for a market.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_market_orderbook(ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Market ticker. (required)
        :param int depth: Depth specifies the maximum number of orderbook price levels on either side.
        :return: GetMarketOrderbookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_market_orderbook_with_http_info(ticker, **kwargs)  # noqa: E501
        else:
            (data) = self.get_market_orderbook_with_http_info(ticker, **kwargs)  # noqa: E501
            return data

    def get_market_orderbook_with_http_info(self, ticker, **kwargs):  # noqa: E501
        """GetMarketOrderbook  # noqa: E501

        Endpoint for getting the orderbook for a market.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_market_orderbook_with_http_info(ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Market ticker. (required)
        :param int depth: Depth specifies the maximum number of orderbook price levels on either side.
        :return: GetMarketOrderbookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ticker', 'depth']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_market_orderbook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ticker' is set
        if ('ticker' not in params or
                params['ticker'] is None):
            raise ValueError("Missing the required parameter `ticker` when calling `get_market_orderbook`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'ticker' in params:
            path_params['ticker'] = params['ticker']  # noqa: E501

        query_params = []
        if 'depth' in params:
            query_params.append(('depth', params['depth']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/markets/{ticker}/orderbook', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetMarketOrderbookResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_markets(self, **kwargs):  # noqa: E501
        """GetMarkets  # noqa: E501

        Endpoint for listing and discovering markets on Kalshi.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_markets(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like tickers, max_ts or min_ts were passed in the original query they must be passed again.
        :param str event_ticker: Event ticker to retrieve markets for.
        :param str series_ticker: Series ticker to retrieve contracts for.
        :param int max_close_ts: Restricts the markets to those that are closing in or before this timestamp.
        :param int min_close_ts: Restricts the markets to those that are closing in or after this timestamp.
        :param str status: Restricts the markets to those with certain statuses, as a comma separated list. The following values are accepted: open, closed, settled.
        :param str tickers: Restricts the markets to those with certain tickers, as a comma separated list.
        :return: GetMarketsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_markets_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_markets_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_markets_with_http_info(self, **kwargs):  # noqa: E501
        """GetMarkets  # noqa: E501

        Endpoint for listing and discovering markets on Kalshi.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_markets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like tickers, max_ts or min_ts were passed in the original query they must be passed again.
        :param str event_ticker: Event ticker to retrieve markets for.
        :param str series_ticker: Series ticker to retrieve contracts for.
        :param int max_close_ts: Restricts the markets to those that are closing in or before this timestamp.
        :param int min_close_ts: Restricts the markets to those that are closing in or after this timestamp.
        :param str status: Restricts the markets to those with certain statuses, as a comma separated list. The following values are accepted: open, closed, settled.
        :param str tickers: Restricts the markets to those with certain tickers, as a comma separated list.
        :return: GetMarketsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['limit', 'cursor', 'event_ticker', 'series_ticker', 'max_close_ts', 'min_close_ts', 'status', 'tickers']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_markets" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501
        if 'event_ticker' in params:
            query_params.append(('event_ticker', params['event_ticker']))  # noqa: E501
        if 'series_ticker' in params:
            query_params.append(('series_ticker', params['series_ticker']))  # noqa: E501
        if 'max_close_ts' in params:
            query_params.append(('max_close_ts', params['max_close_ts']))  # noqa: E501
        if 'min_close_ts' in params:
            query_params.append(('min_close_ts', params['min_close_ts']))  # noqa: E501
        if 'status' in params:
            query_params.append(('status', params['status']))  # noqa: E501
        if 'tickers' in params:
            query_params.append(('tickers', params['tickers']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/markets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetMarketsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_series(self, series_ticker, **kwargs):  # noqa: E501
        """GetSeries  # noqa: E501

        Endpoint for getting data about a series by its ticker.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_series(series_ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str series_ticker: Should be filled with the ticker of the series. (required)
        :return: GetSeriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_series_with_http_info(series_ticker, **kwargs)  # noqa: E501
        else:
            (data) = self.get_series_with_http_info(series_ticker, **kwargs)  # noqa: E501
            return data

    def get_series_with_http_info(self, series_ticker, **kwargs):  # noqa: E501
        """GetSeries  # noqa: E501

        Endpoint for getting data about a series by its ticker.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_series_with_http_info(series_ticker, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str series_ticker: Should be filled with the ticker of the series. (required)
        :return: GetSeriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['series_ticker']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_series" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'series_ticker' is set
        if ('series_ticker' not in params or
                params['series_ticker'] is None):
            raise ValueError("Missing the required parameter `series_ticker` when calling `get_series`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'series_ticker' in params:
            path_params['series_ticker'] = params['series_ticker']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/series/{series_ticker}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSeriesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_trades(self, **kwargs):  # noqa: E501
        """GetTrades  # noqa: E501

        Endpoint for getting all trades for all markets.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_trades(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like ticker, max_ts or min_ts were passed in the original query they must be passed again.
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str ticker: Parameter to specify a specific market to get trades from.
        :param int min_ts: Restricts the response to trades after a timestamp.
        :param int max_ts: Restricts the response to trades before a timestamp.
        :return: PublicTradesGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_trades_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_trades_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_trades_with_http_info(self, **kwargs):  # noqa: E501
        """GetTrades  # noqa: E501

        Endpoint for getting all trades for all markets.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_trades_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like ticker, max_ts or min_ts were passed in the original query they must be passed again.
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str ticker: Parameter to specify a specific market to get trades from.
        :param int min_ts: Restricts the response to trades after a timestamp.
        :param int max_ts: Restricts the response to trades before a timestamp.
        :return: PublicTradesGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cursor', 'limit', 'ticker', 'min_ts', 'max_ts']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_trades" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'ticker' in params:
            query_params.append(('ticker', params['ticker']))  # noqa: E501
        if 'min_ts' in params:
            query_params.append(('min_ts', params['min_ts']))  # noqa: E501
        if 'max_ts' in params:
            query_params.append(('max_ts', params['max_ts']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/markets/trades', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PublicTradesGetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kalshi_python.api_client import ApiClient


class PortfolioApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def batch_cancel_orders(self, body, **kwargs):  # noqa: E501
        """BatchCancelOrders  # noqa: E501

        Endpoint for cancelling up to 20 orders at once. Available to members with advanced access only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.batch_cancel_orders(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BatchCancelOrdersRequest body: Batch orders cancel input data. (required)
        :return: BatchCancelOrdersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.batch_cancel_orders_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.batch_cancel_orders_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def batch_cancel_orders_with_http_info(self, body, **kwargs):  # noqa: E501
        """BatchCancelOrders  # noqa: E501

        Endpoint for cancelling up to 20 orders at once. Available to members with advanced access only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.batch_cancel_orders_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BatchCancelOrdersRequest body: Batch orders cancel input data. (required)
        :return: BatchCancelOrdersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method batch_cancel_orders" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `batch_cancel_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/orders/batched', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BatchCancelOrdersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def batch_create_orders(self, body, **kwargs):  # noqa: E501
        """BatchCreateOrders  # noqa: E501

        Endpoint for submitting a batch of orders.  Each order in the batch is counted against the total rate limit for order operations. Consequently, the size of the batch is capped by the current per-second rate-limit configuration applicable to the user.  At the moment of writing, the limit is 20 orders per batch. Available to members with advanced access only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.batch_create_orders(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BatchCreateOrdersRequest body: Batch order create input data. (required)
        :return: BatchCreateOrdersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.batch_create_orders_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.batch_create_orders_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def batch_create_orders_with_http_info(self, body, **kwargs):  # noqa: E501
        """BatchCreateOrders  # noqa: E501

        Endpoint for submitting a batch of orders.  Each order in the batch is counted against the total rate limit for order operations. Consequently, the size of the batch is capped by the current per-second rate-limit configuration applicable to the user.  At the moment of writing, the limit is 20 orders per batch. Available to members with advanced access only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.batch_create_orders_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BatchCreateOrdersRequest body: Batch order create input data. (required)
        :return: BatchCreateOrdersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method batch_create_orders" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `batch_create_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/orders/batched', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BatchCreateOrdersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cancel_order(self, order_id, **kwargs):  # noqa: E501
        """CancelOrder  # noqa: E501

        Endpoint for canceling orders.  The value for the orderId should match the id field of the order you want to decrease. Commonly, DELETE-type endpoints return 204 status with no body content on success. But we can't completely delete the order, as it may be partially filled already. Instead, the DeleteOrder endpoint reduce the order completely, essentially zeroing the remaining resting contracts on it. The zeroed order is returned on the response payload as a form of validation for the client.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_order(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: Order_id input for the current order. (required)
        :return: CancelOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_order_with_http_info(order_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_order_with_http_info(order_id, **kwargs)  # noqa: E501
            return data

    def cancel_order_with_http_info(self, order_id, **kwargs):  # noqa: E501
        """CancelOrder  # noqa: E501

        Endpoint for canceling orders.  The value for the orderId should match the id field of the order you want to decrease. Commonly, DELETE-type endpoints return 204 status with no body content on success. But we can't completely delete the order, as it may be partially filled already. Instead, the DeleteOrder endpoint reduce the order completely, essentially zeroing the remaining resting contracts on it. The zeroed order is returned on the response payload as a form of validation for the client.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_order_with_http_info(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: Order_id input for the current order. (required)
        :return: CancelOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `cancel_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['order_id'] = params['order_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/orders/{order_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CancelOrderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_order(self, body, **kwargs):  # noqa: E501
        """CreateOrder  # noqa: E501

        Endpoint for submitting orders in a market.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_order(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateOrderRequest body: Order create input data (required)
        :return: CreateOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_order_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_order_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_order_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateOrder  # noqa: E501

        Endpoint for submitting orders in a market.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_order_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateOrderRequest body: Order create input data (required)
        :return: CreateOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/orders', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateOrderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def decrease_order(self, body, order_id, **kwargs):  # noqa: E501
        """DecreaseOrder  # noqa: E501

        Endpoint for decreasing the number of contracts in an existing order. This is the only kind of edit available on order quantity. Cancelling an order is equivalent to decreasing an order amount to zero.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.decrease_order(body, order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DecreaseOrderRequest body: Order data (required)
        :param str order_id: ID of the order to be decreased. (required)
        :return: DecreaseOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.decrease_order_with_http_info(body, order_id, **kwargs)  # noqa: E501
        else:
            (data) = self.decrease_order_with_http_info(body, order_id, **kwargs)  # noqa: E501
            return data

    def decrease_order_with_http_info(self, body, order_id, **kwargs):  # noqa: E501
        """DecreaseOrder  # noqa: E501

        Endpoint for decreasing the number of contracts in an existing order. This is the only kind of edit available on order quantity. Cancelling an order is equivalent to decreasing an order amount to zero.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.decrease_order_with_http_info(body, order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DecreaseOrderRequest body: Order data (required)
        :param str order_id: ID of the order to be decreased. (required)
        :return: DecreaseOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'order_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method decrease_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `decrease_order`")  # noqa: E501
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `decrease_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['order_id'] = params['order_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/orders/{order_id}/decrease', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DecreaseOrderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_balance(self, **kwargs):  # noqa: E501
        """GetBalance  # noqa: E501

        Endpoint for getting the balance of the logged-in member.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_balance(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_balance_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_balance_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_balance_with_http_info(self, **kwargs):  # noqa: E501
        """GetBalance  # noqa: E501

        Endpoint for getting the balance of the logged-in member.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_balance_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_balance" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/balance', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetBalanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_fills(self, **kwargs):  # noqa: E501
        """GetFills  # noqa: E501

        Endpoint for getting all fills for the logged-in member.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_fills(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Restricts the response to trades in a specific market.
        :param str order_id: Restricts the response to trades related to a specific order.
        :param int min_ts: Restricts the response to trades after a timestamp.
        :param int max_ts: Restricts the response to trades before a timestamp.
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like ticker, max_ts or min_ts were passed in the original query they must be passed again.
        :return: GetFillsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_fills_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_fills_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_fills_with_http_info(self, **kwargs):  # noqa: E501
        """GetFills  # noqa: E501

        Endpoint for getting all fills for the logged-in member.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_fills_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Restricts the response to trades in a specific market.
        :param str order_id: Restricts the response to trades related to a specific order.
        :param int min_ts: Restricts the response to trades after a timestamp.
        :param int max_ts: Restricts the response to trades before a timestamp.
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like ticker, max_ts or min_ts were passed in the original query they must be passed again.
        :return: GetFillsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ticker', 'order_id', 'min_ts', 'max_ts', 'limit', 'cursor']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_fills" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ticker' in params:
            query_params.append(('ticker', params['ticker']))  # noqa: E501
        if 'order_id' in params:
            query_params.append(('order_id', params['order_id']))  # noqa: E501
        if 'min_ts' in params:
            query_params.append(('min_ts', params['min_ts']))  # noqa: E501
        if 'max_ts' in params:
            query_params.append(('max_ts', params['max_ts']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/fills', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetFillsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_order(self, order_id, **kwargs):  # noqa: E501
        """GetOrder  # noqa: E501

        Endpoint for getting a single order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: Order_id input for the current order. (required)
        :return: GetOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_order_with_http_info(order_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_order_with_http_info(order_id, **kwargs)  # noqa: E501
            return data

    def get_order_with_http_info(self, order_id, **kwargs):  # noqa: E501
        """GetOrder  # noqa: E501

        Endpoint for getting a single order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_with_http_info(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: Order_id input for the current order. (required)
        :return: GetOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `get_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['order_id'] = params['order_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/orders/{order_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetOrderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_orders(self, **kwargs):  # noqa: E501
        """GetOrders  # noqa: E501

        Endpoint for getting all orders for the logged-in member.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_orders(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Restricts the response to orders in a single market.
        :param str event_ticker: Restricts the response to orders in a single event.
        :param int min_ts: Restricts the response to orders after a timestamp, formatted as a Unix Timestamp.
        :param int max_ts: Restricts the response to orders before a timestamp, formatted as a Unix Timestamp.
        :param str status: Restricts the response to orders that have a certain status: resting, canceled, or executed.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like ticker, max_ts or min_ts were passed in the original query they must be passed again.
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :return: GetOrdersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_orders_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_orders_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_orders_with_http_info(self, **kwargs):  # noqa: E501
        """GetOrders  # noqa: E501

        Endpoint for getting all orders for the logged-in member.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_orders_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ticker: Restricts the response to orders in a single market.
        :param str event_ticker: Restricts the response to orders in a single event.
        :param int min_ts: Restricts the response to orders after a timestamp, formatted as a Unix Timestamp.
        :param int max_ts: Restricts the response to orders before a timestamp, formatted as a Unix Timestamp.
        :param str status: Restricts the response to orders that have a certain status: resting, canceled, or executed.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like ticker, max_ts or min_ts were passed in the original query they must be passed again.
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :return: GetOrdersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ticker', 'event_ticker', 'min_ts', 'max_ts', 'status', 'cursor', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orders" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ticker' in params:
            query_params.append(('ticker', params['ticker']))  # noqa: E501
        if 'event_ticker' in params:
            query_params.append(('event_ticker', params['event_ticker']))  # noqa: E501
        if 'min_ts' in params:
            query_params.append(('min_ts', params['min_ts']))  # noqa: E501
        if 'max_ts' in params:
            query_params.append(('max_ts', params['max_ts']))  # noqa: E501
        if 'status' in params:
            query_params.append(('status', params['status']))  # noqa: E501
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/orders', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetOrdersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_portfolio_settlements(self, **kwargs):  # noqa: E501
        """GetPortfolioSettlements  # noqa: E501

        Endpoint for getting the logged-in member's settlements historical track.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_portfolio_settlements(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query.
        :return: GetPortfolioSettlementsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_portfolio_settlements_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_portfolio_settlements_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_portfolio_settlements_with_http_info(self, **kwargs):  # noqa: E501
        """GetPortfolioSettlements  # noqa: E501

        Endpoint for getting the logged-in member's settlements historical track.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_portfolio_settlements_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query.
        :return: GetPortfolioSettlementsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['limit', 'cursor']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_portfolio_settlements" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/settlements', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetPortfolioSettlementsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_positions(self, **kwargs):  # noqa: E501
        """GetPositions  # noqa: E501

        Endpoint for getting all market positions for the logged-in member.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_positions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like settlement_status, ticker, or event_ticker were passed in the original query they must be passed again.
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str settlement_status: Settlement status of the markets to return. Defaults to unsettled.
        :param str ticker: Ticker of desired positions.
        :param str event_ticker: Event ticker of desired positions.
        :return: GetPositionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_positions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_positions_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_positions_with_http_info(self, **kwargs):  # noqa: E501
        """GetPositions  # noqa: E501

        Endpoint for getting all market positions for the logged-in member.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_positions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cursor: The Cursor represents a pointer to the next page of records in the pagination. So this optional parameter, when filled, should be filled with the cursor string returned in a previous request to this end-point. Filling this would basically tell the api to get the next page containing the number of records passed on the limit parameter. On the other side not filling it tells the api you want to get the first page for another query. The cursor does not store any filters, so if any filter parameters like settlement_status, ticker, or event_ticker were passed in the original query they must be passed again.
        :param int limit: Parameter to specify the number of results per page. Defaults to 20.
        :param str settlement_status: Settlement status of the markets to return. Defaults to unsettled.
        :param str ticker: Ticker of desired positions.
        :param str event_ticker: Event ticker of desired positions.
        :return: GetPositionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cursor', 'limit', 'settlement_status', 'ticker', 'event_ticker']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_positions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'settlement_status' in params:
            query_params.append(('settlement_status', params['settlement_status']))  # noqa: E501
        if 'ticker' in params:
            query_params.append(('ticker', params['ticker']))  # noqa: E501
        if 'event_ticker' in params:
            query_params.append(('event_ticker', params['event_ticker']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer_token']  # noqa: E501

        return self.api_client.call_api(
            '/portfolio/positions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetPositionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PublicTrade(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'int',
        'created_time': 'OutputTime',
        'no_price': 'Cent',
        'taker_side': 'str',
        'ticker': 'str',
        'trade_id': 'str',
        'yes_price': 'Cent'
    }

    attribute_map = {
        'count': 'count',
        'created_time': 'created_time',
        'no_price': 'no_price',
        'taker_side': 'taker_side',
        'ticker': 'ticker',
        'trade_id': 'trade_id',
        'yes_price': 'yes_price'
    }

    def __init__(self, count=None, created_time=None, no_price=None, taker_side=None, ticker=None, trade_id=None, yes_price=None):  # noqa: E501
        """PublicTrade - a model defined in Swagger"""  # noqa: E501
        self._count = None
        self._created_time = None
        self._no_price = None
        self._taker_side = None
        self._ticker = None
        self._trade_id = None
        self._yes_price = None
        self.discriminator = None
        self.count = count
        self.created_time = created_time
        self.no_price = no_price
        self.taker_side = taker_side
        self.ticker = ticker
        self.trade_id = trade_id
        self.yes_price = yes_price

    @property
    def count(self):
        """Gets the count of this PublicTrade.  # noqa: E501

        Number of contracts to be bought or sold.  # noqa: E501

        :return: The count of this PublicTrade.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this PublicTrade.

        Number of contracts to be bought or sold.  # noqa: E501

        :param count: The count of this PublicTrade.  # noqa: E501
        :type: int
        """
        if count is None:
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def created_time(self):
        """Gets the created_time of this PublicTrade.  # noqa: E501


        :return: The created_time of this PublicTrade.  # noqa: E501
        :rtype: OutputTime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this PublicTrade.


        :param created_time: The created_time of this PublicTrade.  # noqa: E501
        :type: OutputTime
        """
        if created_time is None:
            raise ValueError("Invalid value for `created_time`, must not be `None`")  # noqa: E501

        self._created_time = created_time

    @property
    def no_price(self):
        """Gets the no_price of this PublicTrade.  # noqa: E501


        :return: The no_price of this PublicTrade.  # noqa: E501
        :rtype: Cent
        """
        return self._no_price

    @no_price.setter
    def no_price(self, no_price):
        """Sets the no_price of this PublicTrade.


        :param no_price: The no_price of this PublicTrade.  # noqa: E501
        :type: Cent
        """
        if no_price is None:
            raise ValueError("Invalid value for `no_price`, must not be `None`")  # noqa: E501

        self._no_price = no_price

    @property
    def taker_side(self):
        """Gets the taker_side of this PublicTrade.  # noqa: E501

        Side for the taker of this trade.  # noqa: E501

        :return: The taker_side of this PublicTrade.  # noqa: E501
        :rtype: str
        """
        return self._taker_side

    @taker_side.setter
    def taker_side(self, taker_side):
        """Sets the taker_side of this PublicTrade.

        Side for the taker of this trade.  # noqa: E501

        :param taker_side: The taker_side of this PublicTrade.  # noqa: E501
        :type: str
        """
        if taker_side is None:
            raise ValueError("Invalid value for `taker_side`, must not be `None`")  # noqa: E501
        allowed_values = ["yes", "no", "invalid", ""]  # noqa: E501
        if taker_side not in allowed_values:
            raise ValueError(
                "Invalid value for `taker_side` ({0}), must be one of {1}"  # noqa: E501
                .format(taker_side, allowed_values)
            )

        self._taker_side = taker_side

    @property
    def ticker(self):
        """Gets the ticker of this PublicTrade.  # noqa: E501

        Unique identifier for markets.  # noqa: E501

        :return: The ticker of this PublicTrade.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this PublicTrade.

        Unique identifier for markets.  # noqa: E501

        :param ticker: The ticker of this PublicTrade.  # noqa: E501
        :type: str
        """
        if ticker is None:
            raise ValueError("Invalid value for `ticker`, must not be `None`")  # noqa: E501

        self._ticker = ticker

    @property
    def trade_id(self):
        """Gets the trade_id of this PublicTrade.  # noqa: E501

        Unique identifier for this trade.  # noqa: E501

        :return: The trade_id of this PublicTrade.  # noqa: E501
        :rtype: str
        """
        return self._trade_id

    @trade_id.setter
    def trade_id(self, trade_id):
        """Sets the trade_id of this PublicTrade.

        Unique identifier for this trade.  # noqa: E501

        :param trade_id: The trade_id of this PublicTrade.  # noqa: E501
        :type: str
        """
        if trade_id is None:
            raise ValueError("Invalid value for `trade_id`, must not be `None`")  # noqa: E501

        self._trade_id = trade_id

    @property
    def yes_price(self):
        """Gets the yes_price of this PublicTrade.  # noqa: E501


        :return: The yes_price of this PublicTrade.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_price

    @yes_price.setter
    def yes_price(self, yes_price):
        """Sets the yes_price of this PublicTrade.


        :param yes_price: The yes_price of this PublicTrade.  # noqa: E501
        :type: Cent
        """
        if yes_price is None:
            raise ValueError("Invalid value for `yes_price`, must not be `None`")  # noqa: E501

        self._yes_price = yes_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PublicTrade, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicTrade):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Market(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'can_close_early': 'bool',
        'cap_strike': 'Number',
        'category': 'str',
        'close_time': 'OutputTime',
        'custom_strike': 'dict(str, object)',
        'event_ticker': 'str',
        'expiration_time': 'OutputTime',
        'expiration_value': 'str',
        'floor_strike': 'Number',
        'last_price': 'Cent',
        'liquidity': 'Cent',
        'no_ask': 'Cent',
        'no_bid': 'Cent',
        'open_interest': 'int',
        'open_time': 'OutputTime',
        'previous_price': 'Cent',
        'previous_yes_ask': 'Cent',
        'previous_yes_bid': 'Cent',
        'result': 'str',
        'risk_limit_cents': 'Cent',
        'status': 'object',
        'strike_type': 'str',
        'subtitle': 'str',
        'ticker': 'str',
        'volume': 'int',
        'volume_24h': 'int',
        'yes_ask': 'Cent',
        'yes_bid': 'Cent'
    }

    attribute_map = {
        'can_close_early': 'can_close_early',
        'cap_strike': 'cap_strike',
        'category': 'category',
        'close_time': 'close_time',
        'custom_strike': 'custom_strike',
        'event_ticker': 'event_ticker',
        'expiration_time': 'expiration_time',
        'expiration_value': 'expiration_value',
        'floor_strike': 'floor_strike',
        'last_price': 'last_price',
        'liquidity': 'liquidity',
        'no_ask': 'no_ask',
        'no_bid': 'no_bid',
        'open_interest': 'open_interest',
        'open_time': 'open_time',
        'previous_price': 'previous_price',
        'previous_yes_ask': 'previous_yes_ask',
        'previous_yes_bid': 'previous_yes_bid',
        'result': 'result',
        'risk_limit_cents': 'risk_limit_cents',
        'status': 'status',
        'strike_type': 'strike_type',
        'subtitle': 'subtitle',
        'ticker': 'ticker',
        'volume': 'volume',
        'volume_24h': 'volume_24h',
        'yes_ask': 'yes_ask',
        'yes_bid': 'yes_bid'
    }

    def __init__(self, can_close_early=None, cap_strike=None, category=None, close_time=None, custom_strike=None, event_ticker=None, expiration_time=None, expiration_value=None, floor_strike=None, last_price=None, liquidity=None, no_ask=None, no_bid=None, open_interest=None, open_time=None, previous_price=None, previous_yes_ask=None, previous_yes_bid=None, result=None, risk_limit_cents=None, status=None, strike_type=None, subtitle=None, ticker=None, volume=None, volume_24h=None, yes_ask=None, yes_bid=None):  # noqa: E501
        """Market - a model defined in Swagger"""  # noqa: E501
        self._can_close_early = None
        self._cap_strike = None
        self._category = None
        self._close_time = None
        self._custom_strike = None
        self._event_ticker = None
        self._expiration_time = None
        self._expiration_value = None
        self._floor_strike = None
        self._last_price = None
        self._liquidity = None
        self._no_ask = None
        self._no_bid = None
        self._open_interest = None
        self._open_time = None
        self._previous_price = None
        self._previous_yes_ask = None
        self._previous_yes_bid = None
        self._result = None
        self._risk_limit_cents = None
        self._status = None
        self._strike_type = None
        self._subtitle = None
        self._ticker = None
        self._volume = None
        self._volume_24h = None
        self._yes_ask = None
        self._yes_bid = None
        self.discriminator = None
        self.can_close_early = can_close_early
        if cap_strike is not None:
            self.cap_strike = cap_strike
        self.category = category
        self.close_time = close_time
        if custom_strike is not None:
            self.custom_strike = custom_strike
        self.event_ticker = event_ticker
        self.expiration_time = expiration_time
        self.expiration_value = expiration_value
        if floor_strike is not None:
            self.floor_strike = floor_strike
        self.last_price = last_price
        self.liquidity = liquidity
        self.no_ask = no_ask
        self.no_bid = no_bid
        self.open_interest = open_interest
        self.open_time = open_time
        self.previous_price = previous_price
        self.previous_yes_ask = previous_yes_ask
        self.previous_yes_bid = previous_yes_bid
        self.result = result
        self.risk_limit_cents = risk_limit_cents
        self.status = status
        if strike_type is not None:
            self.strike_type = strike_type
        self.subtitle = subtitle
        self.ticker = ticker
        self.volume = volume
        self.volume_24h = volume_24h
        self.yes_ask = yes_ask
        self.yes_bid = yes_bid

    @property
    def can_close_early(self):
        """Gets the can_close_early of this Market.  # noqa: E501

        If true then this market can close earlier then the time provided on close_time.  # noqa: E501

        :return: The can_close_early of this Market.  # noqa: E501
        :rtype: bool
        """
        return self._can_close_early

    @can_close_early.setter
    def can_close_early(self, can_close_early):
        """Sets the can_close_early of this Market.

        If true then this market can close earlier then the time provided on close_time.  # noqa: E501

        :param can_close_early: The can_close_early of this Market.  # noqa: E501
        :type: bool
        """
        if can_close_early is None:
            raise ValueError("Invalid value for `can_close_early`, must not be `None`")  # noqa: E501

        self._can_close_early = can_close_early

    @property
    def cap_strike(self):
        """Gets the cap_strike of this Market.  # noqa: E501


        :return: The cap_strike of this Market.  # noqa: E501
        :rtype: Number
        """
        return self._cap_strike

    @cap_strike.setter
    def cap_strike(self, cap_strike):
        """Sets the cap_strike of this Market.


        :param cap_strike: The cap_strike of this Market.  # noqa: E501
        :type: Number
        """

        self._cap_strike = cap_strike

    @property
    def category(self):
        """Gets the category of this Market.  # noqa: E501

        Category for this market.  # noqa: E501

        :return: The category of this Market.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Market.

        Category for this market.  # noqa: E501

        :param category: The category of this Market.  # noqa: E501
        :type: str
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def close_time(self):
        """Gets the close_time of this Market.  # noqa: E501


        :return: The close_time of this Market.  # noqa: E501
        :rtype: OutputTime
        """
        return self._close_time

    @close_time.setter
    def close_time(self, close_time):
        """Sets the close_time of this Market.


        :param close_time: The close_time of this Market.  # noqa: E501
        :type: OutputTime
        """
        if close_time is None:
            raise ValueError("Invalid value for `close_time`, must not be `None`")  # noqa: E501

        self._close_time = close_time

    @property
    def custom_strike(self):
        """Gets the custom_strike of this Market.  # noqa: E501

        Expiration value for each target that leads to a YES settlement.  Filled only if \"strike_type\" is \"custom\".  # noqa: E501

        :return: The custom_strike of this Market.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._custom_strike

    @custom_strike.setter
    def custom_strike(self, custom_strike):
        """Sets the custom_strike of this Market.

        Expiration value for each target that leads to a YES settlement.  Filled only if \"strike_type\" is \"custom\".  # noqa: E501

        :param custom_strike: The custom_strike of this Market.  # noqa: E501
        :type: dict(str, object)
        """

        self._custom_strike = custom_strike

    @property
    def event_ticker(self):
        """Gets the event_ticker of this Market.  # noqa: E501

        Unique identifier for events.  # noqa: E501

        :return: The event_ticker of this Market.  # noqa: E501
        :rtype: str
        """
        return self._event_ticker

    @event_ticker.setter
    def event_ticker(self, event_ticker):
        """Sets the event_ticker of this Market.

        Unique identifier for events.  # noqa: E501

        :param event_ticker: The event_ticker of this Market.  # noqa: E501
        :type: str
        """
        if event_ticker is None:
            raise ValueError("Invalid value for `event_ticker`, must not be `None`")  # noqa: E501

        self._event_ticker = event_ticker

    @property
    def expiration_time(self):
        """Gets the expiration_time of this Market.  # noqa: E501


        :return: The expiration_time of this Market.  # noqa: E501
        :rtype: OutputTime
        """
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, expiration_time):
        """Sets the expiration_time of this Market.


        :param expiration_time: The expiration_time of this Market.  # noqa: E501
        :type: OutputTime
        """
        if expiration_time is None:
            raise ValueError("Invalid value for `expiration_time`, must not be `None`")  # noqa: E501

        self._expiration_time = expiration_time

    @property
    def expiration_value(self):
        """Gets the expiration_value of this Market.  # noqa: E501

        The value that was considered for the settlement.  # noqa: E501

        :return: The expiration_value of this Market.  # noqa: E501
        :rtype: str
        """
        return self._expiration_value

    @expiration_value.setter
    def expiration_value(self, expiration_value):
        """Sets the expiration_value of this Market.

        The value that was considered for the settlement.  # noqa: E501

        :param expiration_value: The expiration_value of this Market.  # noqa: E501
        :type: str
        """
        if expiration_value is None:
            raise ValueError("Invalid value for `expiration_value`, must not be `None`")  # noqa: E501

        self._expiration_value = expiration_value

    @property
    def floor_strike(self):
        """Gets the floor_strike of this Market.  # noqa: E501


        :return: The floor_strike of this Market.  # noqa: E501
        :rtype: Number
        """
        return self._floor_strike

    @floor_strike.setter
    def floor_strike(self, floor_strike):
        """Sets the floor_strike of this Market.


        :param floor_strike: The floor_strike of this Market.  # noqa: E501
        :type: Number
        """

        self._floor_strike = floor_strike

    @property
    def last_price(self):
        """Gets the last_price of this Market.  # noqa: E501


        :return: The last_price of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._last_price

    @last_price.setter
    def last_price(self, last_price):
        """Sets the last_price of this Market.


        :param last_price: The last_price of this Market.  # noqa: E501
        :type: Cent
        """
        if last_price is None:
            raise ValueError("Invalid value for `last_price`, must not be `None`")  # noqa: E501

        self._last_price = last_price

    @property
    def liquidity(self):
        """Gets the liquidity of this Market.  # noqa: E501


        :return: The liquidity of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._liquidity

    @liquidity.setter
    def liquidity(self, liquidity):
        """Sets the liquidity of this Market.


        :param liquidity: The liquidity of this Market.  # noqa: E501
        :type: Cent
        """
        if liquidity is None:
            raise ValueError("Invalid value for `liquidity`, must not be `None`")  # noqa: E501

        self._liquidity = liquidity

    @property
    def no_ask(self):
        """Gets the no_ask of this Market.  # noqa: E501


        :return: The no_ask of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._no_ask

    @no_ask.setter
    def no_ask(self, no_ask):
        """Sets the no_ask of this Market.


        :param no_ask: The no_ask of this Market.  # noqa: E501
        :type: Cent
        """
        if no_ask is None:
            raise ValueError("Invalid value for `no_ask`, must not be `None`")  # noqa: E501

        self._no_ask = no_ask

    @property
    def no_bid(self):
        """Gets the no_bid of this Market.  # noqa: E501


        :return: The no_bid of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._no_bid

    @no_bid.setter
    def no_bid(self, no_bid):
        """Sets the no_bid of this Market.


        :param no_bid: The no_bid of this Market.  # noqa: E501
        :type: Cent
        """
        if no_bid is None:
            raise ValueError("Invalid value for `no_bid`, must not be `None`")  # noqa: E501

        self._no_bid = no_bid

    @property
    def open_interest(self):
        """Gets the open_interest of this Market.  # noqa: E501

        Number of contracts bought on this market disconsidering netting.  # noqa: E501

        :return: The open_interest of this Market.  # noqa: E501
        :rtype: int
        """
        return self._open_interest

    @open_interest.setter
    def open_interest(self, open_interest):
        """Sets the open_interest of this Market.

        Number of contracts bought on this market disconsidering netting.  # noqa: E501

        :param open_interest: The open_interest of this Market.  # noqa: E501
        :type: int
        """
        if open_interest is None:
            raise ValueError("Invalid value for `open_interest`, must not be `None`")  # noqa: E501

        self._open_interest = open_interest

    @property
    def open_time(self):
        """Gets the open_time of this Market.  # noqa: E501


        :return: The open_time of this Market.  # noqa: E501
        :rtype: OutputTime
        """
        return self._open_time

    @open_time.setter
    def open_time(self, open_time):
        """Sets the open_time of this Market.


        :param open_time: The open_time of this Market.  # noqa: E501
        :type: OutputTime
        """
        if open_time is None:
            raise ValueError("Invalid value for `open_time`, must not be `None`")  # noqa: E501

        self._open_time = open_time

    @property
    def previous_price(self):
        """Gets the previous_price of this Market.  # noqa: E501


        :return: The previous_price of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._previous_price

    @previous_price.setter
    def previous_price(self, previous_price):
        """Sets the previous_price of this Market.


        :param previous_price: The previous_price of this Market.  # noqa: E501
        :type: Cent
        """
        if previous_price is None:
            raise ValueError("Invalid value for `previous_price`, must not be `None`")  # noqa: E501

        self._previous_price = previous_price

    @property
    def previous_yes_ask(self):
        """Gets the previous_yes_ask of this Market.  # noqa: E501


        :return: The previous_yes_ask of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._previous_yes_ask

    @previous_yes_ask.setter
    def previous_yes_ask(self, previous_yes_ask):
        """Sets the previous_yes_ask of this Market.


        :param previous_yes_ask: The previous_yes_ask of this Market.  # noqa: E501
        :type: Cent
        """
        if previous_yes_ask is None:
            raise ValueError("Invalid value for `previous_yes_ask`, must not be `None`")  # noqa: E501

        self._previous_yes_ask = previous_yes_ask

    @property
    def previous_yes_bid(self):
        """Gets the previous_yes_bid of this Market.  # noqa: E501


        :return: The previous_yes_bid of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._previous_yes_bid

    @previous_yes_bid.setter
    def previous_yes_bid(self, previous_yes_bid):
        """Sets the previous_yes_bid of this Market.


        :param previous_yes_bid: The previous_yes_bid of this Market.  # noqa: E501
        :type: Cent
        """
        if previous_yes_bid is None:
            raise ValueError("Invalid value for `previous_yes_bid`, must not be `None`")  # noqa: E501

        self._previous_yes_bid = previous_yes_bid

    @property
    def result(self):
        """Gets the result of this Market.  # noqa: E501

        Settlement result for this market.  # noqa: E501

        :return: The result of this Market.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this Market.

        Settlement result for this market.  # noqa: E501

        :param result: The result of this Market.  # noqa: E501
        :type: str
        """
        if result is None:
            raise ValueError("Invalid value for `result`, must not be `None`")  # noqa: E501
        allowed_values = ["", "yes", "no", "void", "invalid", "all_no", "all_yes"]  # noqa: E501
        if result not in allowed_values:
            raise ValueError(
                "Invalid value for `result` ({0}), must be one of {1}"  # noqa: E501
                .format(result, allowed_values)
            )

        self._result = result

    @property
    def risk_limit_cents(self):
        """Gets the risk_limit_cents of this Market.  # noqa: E501


        :return: The risk_limit_cents of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._risk_limit_cents

    @risk_limit_cents.setter
    def risk_limit_cents(self, risk_limit_cents):
        """Sets the risk_limit_cents of this Market.


        :param risk_limit_cents: The risk_limit_cents of this Market.  # noqa: E501
        :type: Cent
        """
        if risk_limit_cents is None:
            raise ValueError("Invalid value for `risk_limit_cents`, must not be `None`")  # noqa: E501

        self._risk_limit_cents = risk_limit_cents

    @property
    def status(self):
        """Gets the status of this Market.  # noqa: E501

        Represents the current status of a market.  # noqa: E501

        :return: The status of this Market.  # noqa: E501
        :rtype: object
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Market.

        Represents the current status of a market.  # noqa: E501

        :param status: The status of this Market.  # noqa: E501
        :type: object
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def strike_type(self):
        """Gets the strike_type of this Market.  # noqa: E501

        Strike type defines how the market strike (expiration value) is defined and evaluated.  greater: It will be a single number. For YES outcome the expiration value should be greater than \"floor_strike\".  greater_or_equal: It will be a single number. For YES outcome the expiration value should be greater than \"floor_strike\".  less: It will be a single number. For YES outcome the expiration value should be less than \"cap_strike\".  less_or_equal: It will be a single number. For YES outcome the expiration value should be less or equal than \"cap_strike\".  between: It will be two numbers. For YES outcome the expiration value should be between inclusive \"floor_strike\" and \"cap_strike\", that means expiration value needs to be greater or equal \"floor_strike\" and less or equal \"cap_strike\".  custom: It will be one or more non-numerical values. For YES outcome the expiration values should be equal to the values in \"custom_strike\".  # noqa: E501

        :return: The strike_type of this Market.  # noqa: E501
        :rtype: str
        """
        return self._strike_type

    @strike_type.setter
    def strike_type(self, strike_type):
        """Sets the strike_type of this Market.

        Strike type defines how the market strike (expiration value) is defined and evaluated.  greater: It will be a single number. For YES outcome the expiration value should be greater than \"floor_strike\".  greater_or_equal: It will be a single number. For YES outcome the expiration value should be greater than \"floor_strike\".  less: It will be a single number. For YES outcome the expiration value should be less than \"cap_strike\".  less_or_equal: It will be a single number. For YES outcome the expiration value should be less or equal than \"cap_strike\".  between: It will be two numbers. For YES outcome the expiration value should be between inclusive \"floor_strike\" and \"cap_strike\", that means expiration value needs to be greater or equal \"floor_strike\" and less or equal \"cap_strike\".  custom: It will be one or more non-numerical values. For YES outcome the expiration values should be equal to the values in \"custom_strike\".  # noqa: E501

        :param strike_type: The strike_type of this Market.  # noqa: E501
        :type: str
        """
        allowed_values = ["unknown", "greater", "less", "greater_or_equal", "less_or_equal", "between", "custom"]  # noqa: E501
        if strike_type not in allowed_values:
            raise ValueError(
                "Invalid value for `strike_type` ({0}), must be one of {1}"  # noqa: E501
                .format(strike_type, allowed_values)
            )

        self._strike_type = strike_type

    @property
    def subtitle(self):
        """Gets the subtitle of this Market.  # noqa: E501

        Shortened title for this market.  # noqa: E501

        :return: The subtitle of this Market.  # noqa: E501
        :rtype: str
        """
        return self._subtitle

    @subtitle.setter
    def subtitle(self, subtitle):
        """Sets the subtitle of this Market.

        Shortened title for this market.  # noqa: E501

        :param subtitle: The subtitle of this Market.  # noqa: E501
        :type: str
        """
        if subtitle is None:
            raise ValueError("Invalid value for `subtitle`, must not be `None`")  # noqa: E501

        self._subtitle = subtitle

    @property
    def ticker(self):
        """Gets the ticker of this Market.  # noqa: E501

        Unique identifier for markets.  # noqa: E501

        :return: The ticker of this Market.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this Market.

        Unique identifier for markets.  # noqa: E501

        :param ticker: The ticker of this Market.  # noqa: E501
        :type: str
        """
        if ticker is None:
            raise ValueError("Invalid value for `ticker`, must not be `None`")  # noqa: E501

        self._ticker = ticker

    @property
    def volume(self):
        """Gets the volume of this Market.  # noqa: E501

        Number of contracts bought on this market.  # noqa: E501

        :return: The volume of this Market.  # noqa: E501
        :rtype: int
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this Market.

        Number of contracts bought on this market.  # noqa: E501

        :param volume: The volume of this Market.  # noqa: E501
        :type: int
        """
        if volume is None:
            raise ValueError("Invalid value for `volume`, must not be `None`")  # noqa: E501

        self._volume = volume

    @property
    def volume_24h(self):
        """Gets the volume_24h of this Market.  # noqa: E501

        Number of contracts bought on this market in the past day.  # noqa: E501

        :return: The volume_24h of this Market.  # noqa: E501
        :rtype: int
        """
        return self._volume_24h

    @volume_24h.setter
    def volume_24h(self, volume_24h):
        """Sets the volume_24h of this Market.

        Number of contracts bought on this market in the past day.  # noqa: E501

        :param volume_24h: The volume_24h of this Market.  # noqa: E501
        :type: int
        """
        if volume_24h is None:
            raise ValueError("Invalid value for `volume_24h`, must not be `None`")  # noqa: E501

        self._volume_24h = volume_24h

    @property
    def yes_ask(self):
        """Gets the yes_ask of this Market.  # noqa: E501


        :return: The yes_ask of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_ask

    @yes_ask.setter
    def yes_ask(self, yes_ask):
        """Sets the yes_ask of this Market.


        :param yes_ask: The yes_ask of this Market.  # noqa: E501
        :type: Cent
        """
        if yes_ask is None:
            raise ValueError("Invalid value for `yes_ask`, must not be `None`")  # noqa: E501

        self._yes_ask = yes_ask

    @property
    def yes_bid(self):
        """Gets the yes_bid of this Market.  # noqa: E501


        :return: The yes_bid of this Market.  # noqa: E501
        :rtype: Cent
        """
        return self._yes_bid

    @yes_bid.setter
    def yes_bid(self, yes_bid):
        """Sets the yes_bid of this Market.


        :param yes_bid: The yes_bid of this Market.  # noqa: E501
        :type: Cent
        """
        if yes_bid is None:
            raise ValueError("Invalid value for `yes_bid`, must not be `None`")  # noqa: E501

        self._yes_bid = yes_bid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Market, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Market):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ExchangeStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'exchange_active': 'bool',
        'trading_active': 'bool'
    }

    attribute_map = {
        'exchange_active': 'exchange_active',
        'trading_active': 'trading_active'
    }

    def __init__(self, exchange_active=None, trading_active=None):  # noqa: E501
        """ExchangeStatus - a model defined in Swagger"""  # noqa: E501
        self._exchange_active = None
        self._trading_active = None
        self.discriminator = None
        self.exchange_active = exchange_active
        self.trading_active = trading_active

    @property
    def exchange_active(self):
        """Gets the exchange_active of this ExchangeStatus.  # noqa: E501

        False if the core Kalshi exchange is no longer taking any state changes at all. This includes but is not limited to trading, new users, and transfers. True unless we are under maintenance.  # noqa: E501

        :return: The exchange_active of this ExchangeStatus.  # noqa: E501
        :rtype: bool
        """
        return self._exchange_active

    @exchange_active.setter
    def exchange_active(self, exchange_active):
        """Sets the exchange_active of this ExchangeStatus.

        False if the core Kalshi exchange is no longer taking any state changes at all. This includes but is not limited to trading, new users, and transfers. True unless we are under maintenance.  # noqa: E501

        :param exchange_active: The exchange_active of this ExchangeStatus.  # noqa: E501
        :type: bool
        """
        if exchange_active is None:
            raise ValueError("Invalid value for `exchange_active`, must not be `None`")  # noqa: E501

        self._exchange_active = exchange_active

    @property
    def trading_active(self):
        """Gets the trading_active of this ExchangeStatus.  # noqa: E501

        True if we are currently permitting trading on the exchange. This is true during trading hours and false outside exchange hours. Kalshi reserves the right to pause at any time in case issues are detected.  # noqa: E501

        :return: The trading_active of this ExchangeStatus.  # noqa: E501
        :rtype: bool
        """
        return self._trading_active

    @trading_active.setter
    def trading_active(self, trading_active):
        """Sets the trading_active of this ExchangeStatus.

        True if we are currently permitting trading on the exchange. This is true during trading hours and false outside exchange hours. Kalshi reserves the right to pause at any time in case issues are detected.  # noqa: E501

        :param trading_active: The trading_active of this ExchangeStatus.  # noqa: E501
        :type: bool
        """
        if trading_active is None:
            raise ValueError("Invalid value for `trading_active`, must not be `None`")  # noqa: E501

        self._trading_active = trading_active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExchangeStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExchangeStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
"""
from __future__ import absolute_import

from kalshi_python import ApiClient
from kalshi_python.api import AuthApi, PortfolioApi, MarketApi, ExchangeApi
from kalshi_python.models import LoginRequest
from pprint import pprint


class ApiInstance(object):

    def __init__(self, email=None, password=None, configuration=None, header_name=None, header_value=None,
                 cookie=None):
        # Store credentials if provided
        if email is not None and password is not None:
            self.email = email
            self.password = password

        self.api_client = ApiClient(configuration=configuration, header_name=header_name, header_value=header_value,
                                    cookie=cookie)
        # Set up individual apis
        self.exchange_api = ExchangeApi(self.api_client)
        self.auth_api = AuthApi(self.api_client)
        self.portfolio_api = PortfolioApi(self.api_client)
        self.market_api = MarketApi(self.api_client)

    def set_api_token(self, token):
        self.api_client.configuration.api_key_prefix['Authorization'] = 'Bearer'
        self.api_client.configuration.api_key['Authorization'] = token

    def auto_login_if_possible(self):
        if 'Authorization' in self.api_client.configuration.api_key.keys():
            return

        if hasattr(self, 'email') and hasattr(self, 'password'):
            loginResponse = self.login(LoginRequest(
                email=self.email,
                password=self.password,
            ))
            self.set_api_token(loginResponse.token)

    # Proxy exchange methods
    def get_exchange_status(self, **kwargs):
        return self.exchange_api.get_exchange_status(**kwargs)

    # Proxy auth methods
    def login(self, body, **kwargs):
        response = self.auth_api.login(body, **kwargs)
        return response

    def logout(self, **kwargs):
        return self.auth_api.logout(**kwargs)

    # Proxy market methods
    def get_event(self, event_ticker, **kwargs):
        return self.market_api.get_event(event_ticker, **kwargs)

    def get_market(self, ticker, **kwargs):
        return self.market_api.get_market(ticker, **kwargs)

    def get_market_history(self, ticker, **kwargs):
        return self.market_api.get_market_history(ticker, **kwargs)

    def get_market_orderbook(self, ticker, **kwargs):
        return self.market_api.get_market_orderbook(ticker, **kwargs)

    def get_markets(self, **kwargs):
        return self.market_api.get_markets(**kwargs)

    def get_series(self, series_ticker, **kwargs):
        return self.market_api.get_series(series_ticker, **kwargs)

    def get_trades(self, **kwargs):
        return self.market_api.get_trades(**kwargs)

    # Proxy portfolio methods
    def batch_cancel_orders(self, body, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.batch_cancel_orders(body, **kwargs)

    def batch_create_orders(self, body, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.batch_create_orders(body, **kwargs)

    def cancel_order(self, order_id, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.cancel_order(order_id, **kwargs)

    def create_order(self, body, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.create_order(body, **kwargs)

    def decrease_order(self, body, order_id, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.decrease_order(body, order_id, **kwargs)

    def get_balance(self, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.get_balance(**kwargs)

    def get_fills(self, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.get_fills(**kwargs)

    def get_order(self, order_id, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.get_order(order_id, **kwargs)

    def get_orders(self, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.get_orders(**kwargs)

    def get_portfolio_settlements(self, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.get_portfolio_settlements(**kwargs)

    def get_positions(self, **kwargs):
        self.auto_login_if_possible()
        return self.portfolio_api.get_positions(**kwargs)



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kalshi_python
from kalshi_python.api.exchange_api import ExchangeApi  # noqa: E501
from kalshi_python.rest import ApiException


class TestExchangeApi(unittest.TestCase):
    """ExchangeApi unit test stubs"""

    def setUp(self):
        self.api = ExchangeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_exchange_status(self):
        """Test case for get_exchange_status

        Endpoint for getting the exchange status.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kalshi_python
from kalshi_python.api.market_api import MarketApi  # noqa: E501
from kalshi_python.rest import ApiException


class TestMarketApi(unittest.TestCase):
    """MarketApi unit test stubs"""

    def setUp(self):
        self.api = MarketApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_event(self):
        """Test case for get_event

        GetEvent  # noqa: E501
        """
        pass

    def test_get_market(self):
        """Test case for get_market

        GetMarket  # noqa: E501
        """
        pass

    def test_get_market_history(self):
        """Test case for get_market_history

        GetMarketHistory  # noqa: E501
        """
        pass

    def test_get_market_orderbook(self):
        """Test case for get_market_orderbook

        GetMarketOrderbook  # noqa: E501
        """
        pass

    def test_get_markets(self):
        """Test case for get_markets

        GetMarkets  # noqa: E501
        """
        pass

    def test_get_series(self):
        """Test case for get_series

        GetSeries  # noqa: E501
        """
        pass

    def test_get_trades(self):
        """Test case for get_trades

        GetTrades  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
